import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { LexModelsV2ClientResolvedConfig } from "../LexModelsV2Client";
/**
 * @internal
 */
export interface LexModelsV2HttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface LexModelsV2HttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<LexModelsV2ClientResolvedConfig, HandlerExecutionContext, LexModelsV2HttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultLexModelsV2HttpAuthSchemeParametersProvider: (config: LexModelsV2ClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<LexModelsV2HttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface LexModelsV2HttpAuthSchemeProvider extends HttpAuthSchemeProvider<LexModelsV2HttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultLexModelsV2HttpAuthSchemeProvider: LexModelsV2HttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: LexModelsV2HttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: LexModelsV2HttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
